// Dependencies
const express = require("express");
const mongoose = require("mongoose");
const cors = require("cors");
require("dotenv").config();
const userRoute = require("./routes/user");
const productRoute = require("./routes/product");
const cartRoute = require("./routes/cart");
const orderRoute = require("./routes/order");
const path = require('path'); // Add this line

// Server start
const app = express();

// Middlewares
app.use(express.json());
app.use(express.urlencoded({ extended: true }));
app.use(cors());

// Serve static files from the "uploads" folder
app.use('/uploads', express.static(path.join(__dirname, 'uploads')));

// Database
mongoose
	.connect(process.env.MONGO_URL, {
		useNewUrlParser: true,
		useUnifiedTopology: true,
		dbName: "CAPSTONE-3",
	})
	.then(() => {
		console.log(`Connected to Database ${process.env.MONGO_URL}`);
	})
	.catch((err) => {
		console.log(err);
	});

// Routes
app.use("/order", orderRoute);
app.use("/user", userRoute);
app.use("/product", productRoute);
app.use("/cart", cartRoute);



// Server up
app.listen(process.env.PORT || 4000, () => {
	console.log(`Server is running on port ${process.env.PORT}..`);
});
