const express = require("express")
const router = express.Router()
const productController = require("../controllers/product")
const auth = require("../auth")
const upload = require('../multer');

const { authenticateToken, verifyAdmin, } = auth


router.put('/edit/:productId', productController.editProduct);

router.get("/product-tag", productController.productTag)

// S50
// Create a product route (accessible only by isAdmin)
// Retrieve all products route (accessible to both admin and normal user)

router.post("/create", authenticateToken, verifyAdmin, upload.single('image'), productController.createProduct)


// Retrieve all products route (accessible to both admin and normal user)
router.get("/", authenticateToken, productController.getAllProducts)

// Retrieve all products route (accessible to both admin and normal user)
router.get("/all", authenticateToken, verifyAdmin, productController.getAllProducts)

router.delete('/delete/:id', authenticateToken, verifyAdmin, productController.deleteProduct)

// Retrieve all active products route (accessible to both admin and normal user)
router.get("/active", productController.getActiveProducts)

// S51
// Retrieve a single product by ID
router.get('/:id', productController.getProductById)

// Update product route + admin verification
router.put('/:id', authenticateToken, verifyAdmin, productController.updateProduct)

// Archive a product
router.put('/:productId/archive', authenticateToken, verifyAdmin, productController.archiveProduct)

// Activate a product
router.put('/:productId/activate', authenticateToken, verifyAdmin, productController.activateProduct)


module.exports = router
