import React from "react";
import { Button, Collapse, Col, Row, Table, Form } from "react-bootstrap";
import AddressForm from "./AddressForm"; // Assuming the path is correct

const AddressCollapse = ({
  addressOpen,
  setAddressOpen,
  isCustomerLoggedIn,
  selectedAddress,
  setSelectedAddress,
  handleContinueAddress,
  addAddressFormOpen,
  setAddAddressFormOpen,
  addressFormError,
  addresses,
  handleDeleteAddress,
}) => {
  const handleAddressSelect = (addressId) => {
    // Update the selectedAddressId
    setSelectedAddress(addressId);

    // If you also want to update the selectedAddress object, find the corresponding address
    const selected = addresses.find((address) => address._id === addressId);
    setSelectedAddress(selected);
  };

  return (
    <div className="border rounded mb-3 p-3">
      <h3>
        <div className="d-flex justify-content-between align-items-start">
          <span className="fs-6">2. Address</span>
          <Button
            variant="link"
            onClick={() => setAddressOpen(!addressOpen)}
            aria-controls="addressCollapse"
            aria-expanded={addressOpen}
          >
            <i className={`bi bi-chevron-${addressOpen ? "up" : "down"}`}></i>
          </Button>
        </div>
      </h3>
      <Collapse in={addressOpen}>
        <div id="addressCollapse">
          {isCustomerLoggedIn ? (
            <Row>
              <span className="mb-2" style={{ fontSize: "16px" }}>
                The selected address will be used both as your personal address
                (for invoice) and as your delivery address.
              </span>
              <Col className="border rounded mb-3 p-3" md={6}>
                {/* Left column - Add New Address Form Dropdown */}
                <div>
                  {addAddressFormOpen && (
                    <AddressForm
                      selectedAddress={selectedAddress}
                      setSelectedAddress={setSelectedAddress}
                      handleContinueAddress={handleContinueAddress}
                      addressFormError={addressFormError}
                    />
                  )}

                  <Button
                    className="my-3"
                    variant="primary"
                    onClick={() => setAddAddressFormOpen(!addAddressFormOpen)}
                  >
                    Add New Address
                  </Button>
                </div>
              </Col>

              <Col md={6}>
                {/* Right column - My Addresses from addressForm */}
                {addresses && addresses.length > 0 ? (
                  <Table striped bordered hover>
                    <thead>
                      <tr>
                        <th>My Addresses</th>
                        <th>Actions</th>
                      </tr>
                    </thead>
                    <tbody>
                      {addresses.map((address, index) => (
                        <tr key={index}>
                          <td>
                            <div className="d-flex justify-content-between align-items-center">
                              <Form.Check
                                type="radio"
                                id={`addressRadio${index}`}
                                name="addressRadio"
                                checked={
                                  selectedAddress &&
                                  selectedAddress._id === address._id
                                }
                                onChange={() =>
                                  handleAddressSelect(address._id)
                                }
                              />

                              <p className="mx-3">
                                {address.street}, {address.city},{" "}
                                {address.state}, {address.zipCode},{" "}
                                {address.country}
                              </p>
                            </div>
                          </td>
                          <td>
                            <Button
                              variant="link"
                              className="text-danger"
                              onClick={() => handleDeleteAddress(address._id)}
                            >
                              <i className="bi bi-trash"></i>
                            </Button>
                          </td>
                        </tr>
                      ))}
                    </tbody>
                  </Table>
                ) : (
                  <p>No existing addresses. Add a new address below.</p>
                )}
              </Col>
            </Row>
          ) : (
            <p>User not logged in. Log in to view and manage addresses.</p>
          )}
        </div>
      </Collapse>
    </div>
  );
};

export default AddressCollapse;
