import React from "react";
import { Form, Button } from "react-bootstrap";

const AddressForm = ({
  selectedAddress,
  setSelectedAddress,
  handleContinueAddress,
  addressFormError,
}) => {
  const philippineStates = [
    "...",
    "Abra",
    "Agusan del Norte",
    "Agusan del Sur",
    "Aklan",
    "Albay",
    "Antique",
    "Apayao",
    "Aurora",
    "Basilan",
    "Bataan",
    "Batanes",
    "Batangas",
    "Benguet",
    "Biliran",
    "Bohol",
    "Bukidnon",
    "Bulacan",
    "Cagayan",
    "Camarines Norte",
    "Camarines Sur",
    "Camiguin",
    "Capiz",
    "Catanduanes",
    "Cavite",
    "Cebu",
    "Cotabato",
    "Davao de Oro (formerly Compostela Valley)",
    "Davao del Norte",
    "Davao del Sur",
    "Davao Occidental",
    "Davao Oriental",
    "Dinagat Islands",
    "Eastern Samar",
    "Guimaras",
    "Ifugao",
    "Ilocos Norte",
    "Ilocos Sur",
    "Iloilo",
    "Isabela",
    "Kalinga",
    "La Union",
    "Laguna",
    "Lanao del Norte",
    "Lanao del Sur",
    "Leyte",
    "Maguindanao",
    "Marinduque",
    "Masbate",
    "Misamis Occidental",
    "Misamis Oriental",
    "Mountain Province",
    "Negros Occidental",
    "Negros Oriental",
    "Northern Samar",
    "Nueva Ecija",
    "Nueva Vizcaya",
    "Occidental Mindoro",
    "Oriental Mindoro",
    "Palawan",
    "Pampanga",
    "Pangasinan",
    "Quezon",
    "Quirino",
    "Rizal",
    "Romblon",
    "Samar (Western Samar)",
    "Sarangani",
    "Siquijor",
    "Sorsogon",
    "South Cotabato",
    "Southern Leyte",
    "Sultan Kudarat",
    "Sulu",
    "Surigao del Norte",
    "Surigao del Sur",
    "Tarlac",
    "Tawi-Tawi",
    "Zambales",
    "Zamboanga del Norte",
    "Zamboanga del Sur",
    "Zamboanga Sibugay",
  ];

  const countryStates = ["...", "Philippines"];

  return (
    <Form onSubmit={handleContinueAddress}>
      {/* Address form for adding a new address */}
      <Form.Group controlId="street">
        <Form.Label>Street</Form.Label>
        <Form.Control
          type="text"
          placeholder="Enter street address"
          value={selectedAddress?.street || ""}
          onChange={(e) =>
            setSelectedAddress({
              ...selectedAddress,
              street: e.target.value,
            })
          }
          required
        />
      </Form.Group>
      <Form.Group controlId="zipCode">
        <Form.Label>Zip / Postal Code</Form.Label>
        <Form.Control
          type="text"
          placeholder="Enter zip/postal code"
          value={selectedAddress?.zipCode || ""}
          onChange={(e) =>
            setSelectedAddress({
              ...selectedAddress,
              zipCode: e.target.value,
            })
          }
          required
        />
      </Form.Group>
      <Form.Group controlId="city">
        <Form.Label>City</Form.Label>
        <Form.Control
          type="text"
          placeholder="Enter city"
          value={selectedAddress?.city || ""}
          onChange={(e) =>
            setSelectedAddress({
              ...selectedAddress,
              city: e.target.value,
            })
          }
          required
        />
      </Form.Group>

      <Form.Group controlId="state">
        <Form.Label>State</Form.Label>
        <Form.Control
          as="select"
          value={selectedAddress?.state || ""}
          onChange={(e) =>
            setSelectedAddress({
              ...selectedAddress,
              state: e.target.value,
            })
          }
          required
        >
          {philippineStates.map((state, index) => (
            <option key={index}>{state}</option>
          ))}
        </Form.Control>
      </Form.Group>

      <Form.Group controlId="country">
        <Form.Label>Country</Form.Label>
        <Form.Control
          as="select"
          value={selectedAddress?.country || ""}
          onChange={(e) =>
            setSelectedAddress({
              ...selectedAddress,
              country: e.target.value, // Fix: change state to country
            })
          }
          required
        >
          <option value="">Select Country</option>
          {countryStates.map((country, index) => (
            <option key={index} value={country}>
              {country}
            </option>
          ))}
        </Form.Control>
      </Form.Group>

      <Button className="mt-3" variant="primary" type="submit">
        Continue
      </Button>
      {addressFormError && (
        <div className="text-danger mt-2">{addressFormError}</div>
      )}
    </Form>
  );
};

export default AddressForm;
