// OrderDetails.js
import React from "react";
import PropTypes from "prop-types";

const OrderDetails = ({ orderData }) => {
  if (!orderData) {
    // Handle the case where orderData is not available
    return <div>Loading...</div>;
  }

  const {
    userDetails,
    selectedAddress,
    selectedShippingMethod,
    cartItems,
    appliedPromoCode,
    selectedPaymentOption,
    termsAgreed,
    // Include any other necessary data
  } = orderData;

  return (
    <div>
      <h2>Order Details</h2>

      <h3>User Details</h3>
      <pre>{JSON.stringify(userDetails, null, 2)}</pre>

      <h3>Selected Address</h3>
      <pre>{JSON.stringify(selectedAddress, null, 2)}</pre>

      <h3>Selected Shipping Method</h3>
      <pre>{selectedShippingMethod}</pre>

      <h3>Cart Items</h3>
      <ul>
        {cartItems.map((item, index) => (
          <li key={index}>
            <h4>Item {index + 1}</h4>
            <pre>{JSON.stringify(item, null, 2)}</pre>
          </li>
        ))}
      </ul>

      <h3>Applied Promo Code</h3>
      <pre>{appliedPromoCode}</pre>

      <h3>Selected Payment Option</h3>
      <pre>{selectedPaymentOption}</pre>

      <h3>Terms Agreed</h3>
      <pre>{termsAgreed ? "Agreed" : "Not Agreed"}</pre>

      {/* Include additional sections as needed for other data */}
    </div>
  );
};

// Specify PropTypes for the orderData prop
OrderDetails.propTypes = {
  orderData: PropTypes.shape({
    userDetails: PropTypes.object,
    selectedAddress: PropTypes.object,
    selectedShippingMethod: PropTypes.string,
    cartItems: PropTypes.array,
    appliedPromoCode: PropTypes.string,
    selectedPaymentOption: PropTypes.string,
    termsAgreed: PropTypes.bool,
    // Include PropTypes for other data properties
  }),
};

export default OrderDetails;
