// components/OrderSummary.js
import React from 'react';
import { Col, Table, Form, Button } from 'react-bootstrap';

const OrderSummary = ({
  cartItems,
  shippingFee,
  totalPrice,
  discountAmount,
  promoCode,
  setPromoCode,
  handleApplyPromoCode,
  appliedPromoCode,
}) => {
  return (
    <Col xs={12} md={4} className="text-start">
      <h3>Order Summary</h3>
      <Table striped bordered hover>
        <tbody>
          <tr>
            <td>Total Items</td>
            <td>
              {cartItems.reduce((total, item) => total + item.quantity, 0)}
            </td>
          </tr>
          <tr>
            <td>Shipping Fee</td>
            <td>{new Intl.NumberFormat('en-PH', {
              style: 'currency',
              currency: 'PHP',
            }).format(shippingFee.value)}</td>
          </tr>
          <tr>
            <td>Shipping Details</td>
            <td>{shippingFee.details}</td>
          </tr>

          <tr>
            <td>Total</td>
            <td>
              <strong>{new Intl.NumberFormat('en-PH', {
                style: 'currency',
                currency: 'PHP',
              }).format(totalPrice)}</strong>
            </td>
          </tr>
          <tr>
            <td>Discount</td>
            <td>
              <strong>{discountAmount}%</strong>
            </td>
          </tr>
          <tr>
            <td colSpan="2">
              <Form.Group controlId="promoCode">
                <Form.Label>Promo Code</Form.Label>
                <Form.Control
                  type="text"
                  placeholder="Enter promo code"
                  value={promoCode}
                  onChange={(e) => setPromoCode(e.target.value)}
                />
                <Button
                  className="mt-3"
                  variant="primary"
                  onClick={handleApplyPromoCode}
                >
                  Apply Promo Code
                </Button>
              </Form.Group>
              {appliedPromoCode && (
                <div>
                  <p className="mt-2">
                    Applied Promo Code: <strong>{appliedPromoCode}</strong>
                  </p>
                </div>
              )}
            </td>
          </tr>
        </tbody>
      </Table>
    </Col>
  );
};

export default OrderSummary;
