import React, { useState, useEffect } from "react";
import { Button, Collapse, Form } from "react-bootstrap";
import { useNavigate } from 'react-router-dom';
import PropTypes from "prop-types"; // Import PropTypes
import BankOption from "./BankOption";

const PaymentCollapse = ({
  totalPrice,
  userDetails,
  selectedAddress,
  selectedShippingMethod,
  cartItems,
  appliedPromoCode,
}) => {
  const [paymentOpen, setPaymentOpen] = useState(false);
  const [selectedPaymentOption, setSelectedPaymentOption] = useState(null);
  const [termsAgreed, setTermsAgreed] = useState(false);
  const navigate = useNavigate();

  const handlePaymentOptionChange = (option) => {
    setSelectedPaymentOption(option);
  };

  const handleTermsAgreementChange = () => {
    setTermsAgreed(!termsAgreed);
  };

  const isSubmitButtonDisabled = !termsAgreed || selectedPaymentOption === null;
  
  const handleOrderSubmission = () => {
    try {
      const orderData = {
        userDetails,
        selectedAddress, 
        selectedShippingMethod,
        cartItems,
        appliedPromoCode,
        selectedPaymentOption,
        termsAgreed,
        // Include any other necessary data
      };
  
      // Log the order data to the console for testing
      console.log("Order Data:", orderData);
  
      // Display a success message to the user (for testing)
      console.log("Order submission simulated successfully!");
  
      // Navigate to the order confirmation page with orderData
      navigate("/order-confirmation", { state: { orderData } });
    } catch (error) {
      console.error("Error submitting order:", error);
  
      // Handle general error (for testing)
      console.log("Order submission simulated failed.");
    }
  };
  
  

  return (
    <div className="border rounded mb-3 p-3">
      <h3>
        <div className="d-flex justify-content-between align-items-start">
          <span className="fs-6">4. Payment</span>
          <Button
            variant="link"
            onClick={() => setPaymentOpen(!paymentOpen)}
            aria-controls="paymentCollapse"
            aria-expanded={paymentOpen}
          >
            <i className={`bi bi-chevron-${paymentOpen ? "up" : "down"}`}></i>
          </Button>
        </div>
      </h3>
      <Collapse in={paymentOpen}>
        <div id="paymentCollapse">
          <Form.Group className="mb-3">
            <Form.Label>Select Payment Option:</Form.Label>
            <Form.Control
              as="select"
              value={selectedPaymentOption}
              onChange={(e) => handlePaymentOptionChange(e.target.value)}
            >
              <option value="">Select</option>
              <option value="bank">Bank Option</option>
              {/* Add other payment options here */}
            </Form.Control>
          </Form.Group>

          {selectedPaymentOption === "bank" && (
            <BankOption totalPrice={totalPrice} />
          )}

          {/* Terms Agreement */}
          <Form.Group
            className="mb-3"
            style={{
              backgroundColor: "#343a40",
              padding: "10px",
              borderRadius: "5px",
            }}
          >
            <Form.Check
              type="checkbox"
              label="I agree to the terms of service and will adhere to them unconditionally."
              checked={termsAgreed}
              onChange={handleTermsAgreementChange}
              style={{ color: "white" }}
            />
          </Form.Group>

          {/* Payment Button */}
          <Button
            variant="primary"
            onClick={handleOrderSubmission}
            disabled={isSubmitButtonDisabled}
          >
            Submit Order
          </Button>

          {/* Message below the Payment Button */}
          {!termsAgreed && (
            <div className="mt-2 text-danger">
              Please agree to the terms of service before submitting the order.
            </div>
          )}
        </div>
      </Collapse>
    </div>
  );
};

// Specify PropTypes for each prop used in the component
PaymentCollapse.propTypes = {
  totalPrice: PropTypes.number.isRequired,
  userDetails: PropTypes.object,
  selectedAddress: PropTypes.object,
  selectedShippingMethod: PropTypes.string,
  cartItems: PropTypes.array,
  appliedPromoCode: PropTypes.string,
};

export default PaymentCollapse;
