import React, { useState } from "react";
import { Button, Collapse } from "react-bootstrap";

const ShippingMethodCollapse = ({ shippingMethodOpen, setShippingMethodOpen, setSelectedShippingMethod }) => {
  const [selectedOption, setSelectedOption] = useState(null);

  const handleOptionChange = (option) => {
    setSelectedOption(option);
    setSelectedShippingMethod(option); // Update the parent component state
  };

  return (
    <div className="border rounded mb-3 p-3">
      <h3>
        <div className="d-flex justify-content-between align-items-start">
          <span className="fs-6">3. Shipping Method</span>
          <Button
            variant="link"
            onClick={() => setShippingMethodOpen(!shippingMethodOpen)}
            aria-controls="shippingMethodCollapse"
            aria-expanded={shippingMethodOpen}
          >
            <i
              className={`bi bi-chevron-${shippingMethodOpen ? "up" : "down"}`}
            ></i>
          </Button>
        </div>
      </h3>
      <Collapse in={shippingMethodOpen}>
        <div id="shippingMethodCollapse">
          {/* Infographic-style table for Shipping Methods */}
          <div className="row">
            {/* Option 1 */}
            <div className="col-md-4 mb-3">
              <div
                className="border p-3 text-center"
                style={{ height: "auto" }}
              >
                <div className="d-grid gap-2 justify-content-center">
                  <input
                    type="checkbox"
                    className="form-check-input d-flex justify-content-center mx-auto fs-5"
                    id="option1Checkbox"
                    checked={selectedOption === "courier"}
                    onChange={() => handleOptionChange("courier")}
                  />
                  <i
                    className="bi bi-truck text-primary"
                    style={{ fontSize: "3.7rem" }}
                  ></i>
                  <label
                    className="form-check-label"
                    htmlFor="option1Checkbox"
                  >
                    <strong> Pickup by Courier (Lalamove/Grab)</strong>
                    <br />
                    Note: Customer pays for shipping. Wait for us to notify you
                    that your order is ready before you book your courier.
                  </label>
                </div>
              </div>
            </div>

            {/* Option 2 */}
            <div className="col-md-4 mb-3">
              <div
                className="border p-3 text-center"
                style={{ height: "auto" }}
              >
                <div className="d-grid gap-2 justify-content-center">
                  <input
                    type="checkbox"
                    className="form-check-input d-flex justify-content-center mx-auto fs-5"
                    id="option2Checkbox"
                    checked={selectedOption === "curbside"}
                    onChange={() => handleOptionChange("curbside")}
                  />
                  <i
                    className="bi bi-shop text-primary"
                    style={{ fontSize: "3.7rem" }}
                  ></i>
                  <label
                    className="form-check-label"
                    htmlFor="option2Checkbox"
                  >
                    <strong>Curbside Pickup</strong>
                    <br />
                    Note: Wait for us to notify you that your order is ready
                    before proceeding to our designated pickup area in front of
                    our building.
                  </label>
                </div>
              </div>
            </div>

            {/* Option 3 */}
            <div className="col-md-4 mb-3">
              <div
                className="border p-3 text-center"
                style={{ height: "auto" }}
              >
                <div className="d-grid gap-2 justify-content-center">
                  <input
                    type="checkbox"
                    className="form-check-input d-flex justify-content-center mx-auto fs-5"
                    id="option3Checkbox"
                    checked={selectedOption === "express"}
                    onChange={() => handleOptionChange("express")}
                  />
                  <i
                    className="bi bi-clock text-primary"
                    style={{ fontSize: "3.7rem" }}
                  ></i>
                  <label
                    className="form-check-label"
                    htmlFor="option3Checkbox"
                  >
                    <strong>Local Express Delivery</strong>
                    <br />
                    within 24 - 48 hours during business days
                  </label>
                </div>
              </div>
            </div>
          </div>
        </div>
      </Collapse>
    </div>
  );
};

export default ShippingMethodCollapse;
