import { useContext, useEffect } from 'react';
import { Navigate } from 'react-router-dom';
import { toast } from 'react-toastify';
import 'react-toastify/dist/ReactToastify.css';
import UserContext from '../UserContext';
import { useCart } from '../CartContext';

export default function Logout() {
  const { unsetUser, setUser } = useContext(UserContext);
  const { clearCart } = useCart();

  useEffect(() => {
    const handleLogout = async () => {
      try {
        // Call the clearCart function from the CartContext
        await clearCart();
        // Display success toast for cart clearing, using toastId to ensure it only notifies once
        toast.success('Your cart is cleared.', { position: 'bottom-right', toastId: 'cart-cleared-toast' });
      } catch (error) {
        console.error('Error clearing cart:', error);
      }

      // Unset user locally
      unsetUser();
      setUser({
        id: null,
        isAdmin: null,
      });

      // Redirect back to login
    };

    handleLogout();
  }, [unsetUser, setUser, clearCart]);

  return <Navigate to="/login" />;
}
